summaryrefslogtreecommitdiff
path: root/lib/chef/client.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/chef/client.rb')
-rw-r--r--lib/chef/client.rb12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/chef/client.rb b/lib/chef/client.rb
index a4f15c271f..098345a9e2 100644
--- a/lib/chef/client.rb
+++ b/lib/chef/client.rb
@@ -224,21 +224,21 @@ class Chef
end
# Instantiates a Chef::Node object, possibly loading the node's prior state
# when using chef-client. Delegates to policy_builder
#
- #
- # === Returns
- # Chef::Node:: The node object for this chef run
+ # @return [Chef::Node] The node object for this Chef run
def load_node
policy_builder.load_node
@node = policy_builder.node
+ Chef.set_node(@node)
+ node
end
# Mutates the `node` object to prepare it for the chef run. Delegates to
# policy_builder
#
- # === Returns
- # Chef::Node:: The updated node object
+ # @return [Chef::Node] The updated node object
def build_node
policy_builder.build_node
@run_status = Chef::RunStatus.new(node, events)
@@ -224,21 +224,21 @@ class Chef
end
# Instantiates a Chef::Node object, possibly loading the node's prior state
- # when using chef-client. Delegates to policy_builder
+ # when using chef-client. Delegates to policy_builder. Injects the built node
+ # into the Chef class.
#